@@ -1,8 +1,7 @@
 """命令行执行脚本模块."""
-from .core import ppm
-# from .cmd_reset import *
+from .core import *
 from .project import *
-from .build_ import build
+from .build_ import *
 from .cache import *
 from .doc_ import *
 from .docker_ import *
@@ -13,7 +12,6 @@ from .proto import *
 from .requires import *
 from .schema import *
 from .test_ import *
-from .info import info
-from .run import run_cmd
+from .info import *
+from .run import *
 from .version import __VERSION__
-# from .cmd_stack import *
