@@ -2,4 +2,6 @@ from .info import project_info
 from .add import add_component
 from .new import new_project
 from .as_template import project_as_temp
-# from .build_ import build_doc
+
+
+__all__ = ["project_info", "add_component", "new_project", "project_as_temp"]
