@@ -5,7 +5,7 @@ from typing import List
 from pmfp.utils.run_command_utils import run
 
 
-def build_pb_js(files: List[str], includes: List[str], to: str, cwd: Path,
+def build_pb_js(files: List[str], includes: List[str], to: str, cwd: Path, js_import_style: str,
                 **kwargs: str) -> None:
     """编译js语言模块.
 
@@ -13,6 +13,7 @@ def build_pb_js(files: List[str], includes: List[str], to: str, cwd: Path,
         files (List[str]): 待编译的protobuffer文件
         includes (List[str]): 待编译的protobuffer文件所在的文件夹
         to (str): 编译成的模块文件放到的路径
+        js_import_style (str): 编译出来的js模块形式
 
     """
     includes_str = " ".join([f"-I {include}" for include in includes])
@@ -20,7 +21,8 @@ def build_pb_js(files: List[str], includes: List[str], to: str, cwd: Path,
     flag_str = ""
     if kwargs:
         flag_str += " ".join([f"{k}={v}" for k, v in kwargs.items()])
-    command = f"protoc {includes_str} --js_out=import_style=commonjs,binary:{to} {target_str}"
+    
+    command = f"protoc {includes_str} --js_out=import_style={js_import_style},binary:{to} {target_str}"
     try:
         run(command, cwd=cwd, visible=True)
     except Exception as err:
