@@ -1,11 +1,8 @@
 """version命令的处理."""
-import json
-import configparser
-from pathlib import Path
 from schema_entry import EntryPoint
 from .core import ppm
 
-__VERSION__ = "4.0.9"
+__VERSION__ = "4.1.9"
 
 
 class VERSION(EntryPoint):
@@ -17,3 +14,5 @@ class VERSION(EntryPoint):
 
 
 version = ppm.regist_sub(VERSION)
+
+__all__ = ["__VERSION__"]
